Coverage for project/wsgi.py: 0%

# Coverage for project/wsgi.py : 0%

## 4 statements 0 run 4 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1"""

2 WSGI config for project project.

3

4 It exposes the WSGI callable as a module-level variable named ``application``.

5

6 For more information on this file, see

7 https://docs.djangoproject.com/en/3.0/howto/deployment/wsgi/

8"""

9

10 import os

11

12 from django.core.wsgi import get_wsgi_application

13

14 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'project.settings')

15

16 application = get_wsgi_application()